(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     28337,        980]*)
(*NotebookOutlinePosition[     28972,       1003]*)
(*  CellTagsIndexPosition[     28928,        999]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
    \(path = "\</auto/procsv23/mnt1/lothar/BARRIER/NewMath/\>"; \n
    Get[path<>"\<16_Picture2BarCompareToYamamotoWidth.txt\>"]; \)], "Input"],

Cell["\<\
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/00_definitions.common
setYamamotoFunctions
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/03_definitions.transferMatrix
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/04_definitions.\
singleBarrierMatrix
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/05_definitions.sigma1_e_gt_V1
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/06_definitions.sigma1_e_le_V1
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/08_definitions.\
doubleBarrierMatrix
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/09_definitions.\
doubleBarrierTransmissionCoefficient
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/15_definitions.\
ComputationResonancePeaks
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/16_definitions.\
DerivativesForPeakWidth
<</auto/procsv23/mnt1/lothar/BARRIER/NewMath/16_\
Picture2BarCompareToYamamotoWidth.txt
setPlotFunctions\
\>", "Print"]
}, Open  ]],

Cell["\<\
(* Upper Peak LMS Paper \
**************************************************************** *)\
\>", 
  "Input"],

Cell[CellGroupData[{

Cell["\<\
deltaXiHigh=deltaXiB1eLeV1V2[ k[m,resonanceEnergyHigh]
                             ,m
                             ,b1
                             ,I beta1[m1,resonanceEnergyHigh,V1]
                             ,m1
                            ]
\
\>", "Input"],

Cell[OutputFormData["\<\
3.104497580430733*^7\
\>", "\<\
         7
3.1045 10\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
deltaHHigh=deltaHB1eLeV1V2[  k[m,resonanceEnergyHigh]
                            ,m
                            ,b1
                            ,beta1[m1,resonanceEnergyHigh,V1]
                            ,m1
                          ]
\
\>", "Input"],

Cell[OutputFormData["\<\
1.449712913338725*^9\
\>", "\<\
          9
1.44971 10\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
peakWidthHigh=(    sigmaHFactor[sigmaResonanceEnergyHigh]   \
deltaHHigh^2
                +  sigmaXiFactor[sigmaResonanceEnergyHigh]  deltaXiHigh^2
              )^(-1/2)
\
\>", "Input"],

Cell[OutputFormData["\<\
1.820924243919212*^-9\
\>", "\<\
          -9
1.82092 10\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["peakWidthHigh/nanometer", "Input"],

Cell[OutputFormData["\<\
1.820924243919212\
\>", "\<\
1.82092\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["peakWidthHigh /b1", "Input"],

Cell[OutputFormData["\<\
0.455231060979803\
\>", "\<\
0.455231\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
e=resonanceEnergyHigh;
b1Half=b1+peakWidthHigh;
tau2[ b1Half
     ,I beta1[m1,e,V1]
     ,m1
     ,w
     ,k[m,e]
     ,m
     ,b2
     ,I beta1[m2,e,V2]
     ,m2
    ]\
\>", "Input"],

Cell[OutputFormData["\<\
0.4552712345468663\
\>", 
"\<\
0.455271\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Plot[{
tau2[ t*b1
     ,I beta1[m1,e,V1]
     ,m1
     ,w
     ,k[m,e]
     ,m
     ,b2
     ,I beta1[m2,e,V2]
     ,m2
    ]
,
(  1  +  (   sigmaHFactor[sigmaResonanceEnergyHigh]   deltaHHigh^2 
           + sigmaXiFactor[sigmaResonanceEnergyHigh] deltaXiHigh^2 
         )*( (t-1) b1 )^2 
)^(-1)
}
,{t,.2,1.8}
]\
\>", "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.529101 0.0147151 0.588604 [
[.15608 .00222 -12 -9 ]
[.15608 .00222 12 0 ]
[.28836 .00222 -9 -9 ]
[.28836 .00222 9 0 ]
[.42063 .00222 -12 -9 ]
[.42063 .00222 12 0 ]
[.55291 .00222 -3 -9 ]
[.55291 .00222 3 0 ]
[.68519 .00222 -12 -9 ]
[.68519 .00222 12 0 ]
[.81746 .00222 -9 -9 ]
[.81746 .00222 9 0 ]
[.94974 .00222 -12 -9 ]
[.94974 .00222 12 0 ]
[.01131 .13244 -18 -4.5 ]
[.01131 .13244 0 4.5 ]
[.01131 .25016 -18 -4.5 ]
[.01131 .25016 0 4.5 ]
[.01131 .36788 -18 -4.5 ]
[.01131 .36788 0 4.5 ]
[.01131 .4856 -18 -4.5 ]
[.01131 .4856 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15608 .01472 m
.15608 .02097 L
s
[(0.25)] .15608 .00222 0 1 Mshowa
.28836 .01472 m
.28836 .02097 L
s
[(0.5)] .28836 .00222 0 1 Mshowa
.42063 .01472 m
.42063 .02097 L
s
[(0.75)] .42063 .00222 0 1 Mshowa
.55291 .01472 m
.55291 .02097 L
s
[(1)] .55291 .00222 0 1 Mshowa
.68519 .01472 m
.68519 .02097 L
s
[(1.25)] .68519 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(1.5)] .81746 .00222 0 1 Mshowa
.94974 .01472 m
.94974 .02097 L
s
[(1.75)] .94974 .00222 0 1 Mshowa
.125 Mabswid
.05026 .01472 m
.05026 .01847 L
s
.07672 .01472 m
.07672 .01847 L
s
.10317 .01472 m
.10317 .01847 L
s
.12963 .01472 m
.12963 .01847 L
s
.18254 .01472 m
.18254 .01847 L
s
.20899 .01472 m
.20899 .01847 L
s
.23545 .01472 m
.23545 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.31481 .01472 m
.31481 .01847 L
s
.34127 .01472 m
.34127 .01847 L
s
.36772 .01472 m
.36772 .01847 L
s
.39418 .01472 m
.39418 .01847 L
s
.44709 .01472 m
.44709 .01847 L
s
.47354 .01472 m
.47354 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.52646 .01472 m
.52646 .01847 L
s
.57937 .01472 m
.57937 .01847 L
s
.60582 .01472 m
.60582 .01847 L
s
.63228 .01472 m
.63228 .01847 L
s
.65873 .01472 m
.65873 .01847 L
s
.71164 .01472 m
.71164 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.76455 .01472 m
.76455 .01847 L
s
.79101 .01472 m
.79101 .01847 L
s
.84392 .01472 m
.84392 .01847 L
s
.87037 .01472 m
.87037 .01847 L
s
.89683 .01472 m
.89683 .01847 L
s
.92328 .01472 m
.92328 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .13244 m
.03006 .13244 L
s
[(0.2)] .01131 .13244 1 0 Mshowa
.02381 .25016 m
.03006 .25016 L
s
[(0.4)] .01131 .25016 1 0 Mshowa
.02381 .36788 m
.03006 .36788 L
s
[(0.6)] .01131 .36788 1 0 Mshowa
.02381 .4856 m
.03006 .4856 L
s
[(0.8)] .01131 .4856 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .16187 m
.02756 .16187 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .30902 m
.02756 .30902 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .45617 m
.02756 .45617 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.12963 .10853 m
.16397 .12987 L
.20143 .15836 L
.2366 .19089 L
.27043 .22817 L
.30644 .27478 L
.3411 .32633 L
.37794 .38711 L
.41343 .44867 L
.44758 .50603 L
.46486 .53243 L
.4839 .55805 L
.50217 .57811 L
.51888 .59176 L
.52773 .59694 L
.53179 .59882 L
.53613 .60047 L
.53855 .60123 L
.54073 .60182 L
.54296 .60232 L
.54501 .60269 L
.5474 .60301 L
.54866 .60314 L
.5493 .60319 L
.54999 .60323 L
.55115 .60329 L
.55223 .60331 L
.55289 .60332 L
.55352 .60332 L
.55469 .60329 L
.5557 .60324 L
.5568 .60317 L
.55783 .60307 L
.55877 .60297 L
.56096 .60266 L
.56327 .60223 L
.56763 .60113 L
.57239 .59949 L
.58087 .59547 L
.58876 .59051 L
.60695 .57487 L
.62347 .55612 L
.65901 .50481 L
.6932 .44726 L
.72957 .38422 L
.7646 .32652 L
.79828 .27633 L
.83413 .22967 L
.86864 .19148 L
.90533 .15757 L
Mistroke
.94068 .13068 L
.97467 .10939 L
.97619 .10853 L
Mfstroke
.12963 .15869 m
.16397 .17788 L
.20143 .2028 L
.2366 .23075 L
.27043 .2625 L
.30644 .30224 L
.3411 .34663 L
.37794 .4 L
.41343 .45551 L
.44758 .50882 L
.46486 .53394 L
.4839 .55867 L
.50217 .57831 L
.51888 .5918 L
.52773 .59695 L
.53179 .59883 L
.53613 .60048 L
.53855 .60123 L
.54073 .60182 L
.54296 .60232 L
.54501 .60269 L
.5474 .60301 L
.54866 .60314 L
.5493 .60319 L
.54999 .60323 L
.55115 .60329 L
.55223 .60331 L
.55289 .60332 L
.55352 .60332 L
.55469 .60329 L
.5557 .60324 L
.5568 .60317 L
.55783 .60307 L
.55877 .60297 L
.56096 .60266 L
.56327 .60223 L
.56763 .60113 L
.57239 .59949 L
.58087 .59549 L
.58876 .59056 L
.60695 .57511 L
.62347 .5568 L
.65901 .50767 L
.6932 .45422 L
.72957 .39743 L
.7646 .34681 L
.79828 .30357 L
.83413 .26378 L
.86864 .23125 L
.90533 .20212 L
Mistroke
.94068 .17859 L
.97467 .15947 L
.97619 .15869 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/@P10`4000010?ooo`0006BEkOl0003o
0?oo0000ool0o`3ooonUChj>S_oTa?GemOoN[M?CdmWIfGAdM:VYZEnNX39DEKWEeW:OolCGociGS<d0
0;no_de=CF67fNKViW=cLjo^k[jn_ZG0`FA>BjVmj?l0VJRmj:Nlj:JljJ>kjYZhk7n[l011`_JPCObf
Hog5HOOILNkXa[C^]000?`00Onc/k:>SXk0`H<?3`m0PT:0Pl3bcLLk>c/C4a;Zj^[6a/JRXZ:2PX=Ro
f000_`0o000o?h:2PWmoO`0oO`0o_`0oo`1o001o?`1oO`1o_`1oo`2o002o?`2oO`2o_`2oo`3o?`3o
O`3o_cl003l0?cl0Ocl0_cl0oclo07EeMGalO3lo?cloOclo_cloocmo03mo?cmoOcmo_cmoocno03no
?cnoOcno_cnoocoo03oo?cooOcoo_cooogl007l0?gl0Ogl0_gl0oglo07lo?gloOglo_gloogmo07mo
?gmo_gmoogno07no?gnoOgno_gnoogoo07oo?gooOgoo_goookl00;l0?kl0Okl0_kl0oklo0;lo?klo
Oklo_klookmo0;mo?kmoOkmo_kmookno0;no?knoOknookoo0;oo?kooOkoo_kooool0?ol0Ool0_olo
0?lo?oloOolo_olooomo0?mo?omoOomo_omooono0?no?onoOono_onooooo?oooOooo_h9cPYVIVN[Z
jZNWYjj^[WMgMm3Hgko>i[K8j;75j?ooonk^k]gMgLc<c;^k^jZZZYVIVHR8R7MgMfIVIUEEEDA4A3<c
<b8R8Q4A4@000:o3jJg1jJc0jJ^ojJZojJVojJVnjJRnjJNmjJJmjJFljJBkjJBjjJ>jjJ6ijJ2gjIjf
jIbdjIVaj9J^j9:[ihfUiHJOhgjGh7F<g6UoeUeacU1PaD=@^SQ1[c4eYRd^Wbh[Vc<]VShfWeA?[j>l
j`00@PP0C`d0D0`0B`P0@P40=0008@001jNmj9bhk8N_kol08@000?l08@000?l08@0002l00P440003
0@000080104200<14`020@@000<100000P030A<00P4400030@0000<000<100000P030AP0104G00@1
0`000`40000200@10P030A80104300030@0000800`4B00@10`000`40000300030@0000800`450000
;P001040004800030@0000H000<100003`001040004;00030@0000l000@100012@000`4000050003
0@0001L000<1000060000`40000700030@0000H000<100004@000`40000:00030@00014000<10000
20000`40000500030@000080000^00040@000@T000<100001@000`40000?00040@000@/000<10000
3`001040004:00030@0000@000<100005`000`40000H00030@0000P000<100001@000`40000A0003
0@0000X000<100004@000`40000900030@0000@000<100000P0002h000@100012P00104000030A80
00@1000120030A8000@100012P00104000030AX000<1000060000`40000900040@0000<150000`40
000700<150000`40000900040@0000<11@0002h000@100012`001040004D00040@000@P000<10000
4P001040004;00040@000A`000<1000060000`40000:00040@000AH000<100001`000`40000D0003
0@0000X000@100011`0001D000<100005P001040004800040@000@8000<100004P00104000480003
0@00018000@1000120001040004200030@0001P00`4H00<12@001040004200030@0001800`490003
0@0001800`4900040@000@8000<100001@0001D000<100005`020@X00P4300@14P020@T0104B0081
2@040@80104I00030@0001P000<1000020020@<0104C00030@0000L0104C00030@0000L0104200@1
100001D000<10000o`0900005@000`40003o00T0000?0?l14@4100005@000`40000400030@0000@0
00<100001@000`40000400030@0000@000<1000010000`40000400030@0000D000<1000010000`40
000400030@0000@000<1000010000`40000400030@0000D000<1000010000`40000400030@0000@0
00<1000010000`40000500030@0000@000<1000010000`40000400030@0000@000<100001@000`40
000400030@0000@000<1000010000`40000400030@0000D000<1000010000`40000400030@0000@0
00<1000010000`40000500030@0000@000<1000010000`40000500005@000`40000Q00030@000240
00<100008@000`40000Q00030@00024000<100008@000`40000Q00030@0000`0000E00030@000?l0
2@0001D000<10000o`0900005@000`40003o00T0000E00030@000?l02@0001D000<10000o`090000
5@020Ol02P0001D000<10000o`0900005@000`40003o00T0000E00030@000?l02@0001D000<10000
o`0900005@000`40003o00T0000E00030@000?l02@0001D000<10000o`0900005@020Ol02P0001D0
00<10000o`0900005@000`40003o00T0000E00030@000?l02@0001D000<10000o`0900005@000`40
003o00T0000E00030@000?l02@0001D000<10000o`0900005@020Ol02P0001D000<100006P000`40
003S00030@0000D0000E00030@0001/00P7R00811`0001D000<100007@000`40003M00812@0001D0
00<100007P020M/00P4;00005@000`40000P00030@000=H00P4=00005@000`40000Q0081e0020@l0
0002008110000`40000200@110000`40000S00030@000=0000<100003`0000050040004020000`40
000500<190000`40003>00030@00010000001@01000100T000<1000010000`40000U0081c@000`40
000A000000D00@000@0:00030@0000<000<100009`000`40003900030@00018000001@01000100/0
00<100000P000`40000X00030@000<H00P4E000000D00@000@0800040@000@@000<10000:@000`40
003400030@0001D0000200812P020@D000<10000:P020L<000<100005P0001D000<10000;0000`40
002o00030@0001L0000E00030@0001X000<1000040000`40002m00030@00010000<100001@0001D0
0P4L00814@000`40002k00030@0000l00P4800005@000`40000M008140000`40002i00030@0000h0
0P4:00005@000`40000O00813`000`40002g00030@0000h000<100002P0001D000<100008@020@h0
00<10000]0020@l00P4=00005@000`40000S00030@0000`00P6c00030@0000d00P4?00005@000`40
000T00813P000`40002_00030@0000d000<100003`0001D000<100009P000`40000<00030@000:d0
00<1000030020A80000E00030@0002L000<1000030000`40002[00030@0000`000<100004P0001D0
0P4Y00813@000`40002Y00030@0000/00P4E00005@000`40000Z00030@0000/000<10000Y`000`40
000;00030@0001D0000E00030@0002/00P4<00030@000:D000<100002P020AP0000E00030@0002d0
00<100002P000`40002S00030@0000X000<10000600001D000<10000;P000`40000:00030@000:40
00<100002P000`40000I00005@000`40000_00812`000`40002O00030@0000T00P4L00005@000`40
000a00030@0000P000<10000WP000`40000900030@0001`0000E00030@00038000<1000020000`40
002L00030@0000T000<100007@0001D00P4d00030@0000P000<10000VP000`40000900030@0001h0
000E00030@0003@00P4900030@0009P000<1000020020B40000E00030@0003H000<100001`000`40
002F00030@0000P000<100008@0001D000<10000=`000`40000700030@0009@000<1000020000`40
000R00005@000`40000h00030@0000L000<10000T`000`40000700030@0002<0000E00030@0003T0
00<100001P000`40002B00030@0000L000<10000900001D000<10000>P000`40000600030@000900
00<100001`000`40000U00000P020@@000<1000010000`40000300030@0003/00P4700030@0008l0
00<100001@020BP000001@01000100X000<100000`030Cd000<100001@000`40002=00030@0000D0
00<10000:0000005004000401`050@@000<10000?P000`40000400030@0008`000<100001@000`40
000Y000000D00@000@0700040@000@D000<10000?`000`40000400030@0008X000<100001@000`40
000Z000000D00@000@0800030@0100D000<10000@0000`40000400030@0008T000<1000010000`40
000[000000D00@000@0900811@000`40001100030@0000@000<10000Q`000`40000400030@0002`0
000200812`000`40000300030@00048000<100000`000`40002600030@0000@000<10000;@0001D0
00<10000@`000`40000300030@0008D000<100000`000`40000^00005@000`40001400030@0000<0
00<10000P`000`40000300030@0002l0000E0081AP000`40000300030@00084000<100000`000`40
000`00005@000`40001500030@0000<000<10000P@000`40000300030@000300000E00030@0004H0
00<100000`000`40001o00030@0000<000<10000<@0001D000<10000A`000`40000300030@0007d0
00<100000`000`40000b00005@000`40001800030@00008000<10000O0000`40000300030@0003<0
000E00030@0004T000<100000P000`40001k00030@00008000<10000=00001D000<10000BP000`40
000200030@0007T000<100000P000`40000e00005@000`40001;00050@000040NP000`4000020003
0@0003H0000E0081C@001@40000107T000D100000@0i00005@000`40001<00050@000040N0000`40
000200030@0003L0000E00030@0004d000D100000@1f00030@00008000<10000>00001D000<10000
CP001@40000107@000<100000P000`40000i00005@000`40001?00040@000G@000D100000@0l0000
5@000`40001?00050@000040LP001@40000103d0000E00030@00050000D100000@1`00050@000040
?P0001D000<10000D@001040005`00050@000040?P0001D00P5C00040@000Fh000D100000@0o0000
5@000`40001B00050@000040K@001040005000005@000`40001C00040@000F`000@10001@@0001D0
00<10000E0001040005Z00040@000D80000E00030@0005@000@10001JP001040005200005@000`40
001E00040@000FP000@10001@`0001D000<10000EP001040005W00030@0104@00002008110000`40
000300811@000`40001F00040@000FH000@10001A00000050040004020001040004400<1E`001040
005T00040@000DD000001@01000100P000@1000110000`40001H00040@000F<000@10001A@000005
0040004020030@D000<10000F0001040005R00040@000DH000001@01000100P000<100001@000`40
001I00040@000F4000<10040A`0000050040004020000`40000500030@0005X000<10040H0001040
005700000P020@X00`4400030@0005X000@10001GP001040005800005@000`40001K00040@000Ed0
00<10040B@0001D000<10000G0000`400@1L00040@000DT0000E0081G@001040005K00030@0104X0
000E00030@0005d000<10040FP000`400@1;00005@000`40001N00030@0105T000<10040B`0001D0
00<10000GP001040005G00030@0104`0000E00030@0005l000<10040E`020Dd0000E00030@000600
00<10040E@000`400@1=00005@000`40001P00030@0105@000<10040CP0001D000<10000H@000`40
0@1C0081C`0001D00P5S0081DP000`400@1?00005@000`40001R00030@0105400P5@00005@000`40
001S00030@0104l00P5A00005@000`40001T0081C`020E40000E00030@0006@000<10040C@020E80
000E00030@0006D00P5=00030@000540000E00030@0006H00P5;0081D`0001D000<10000IP000`40
0@190081E00001D00P5X0081B@000`40001C00005@000`40001X0081A`020ED0000E00030@0006P0
0P5700030@0005@0000E00030@0006T00P550081EP0001D000<10000JP000`4000120081E`0001D0
00<10000JP020D<000<10000EP0001D000<10000J`020D400P5H00000P020@@000<100000`020@D0
00<10000K0000`40000o00030@0005L000001@01000100P000@1000110030F`00P4o0081F@000005
0040004020001040004400030@0006d000<10000?0020EX000001@01000100T00P4500030@0006d0
0P4m00030@0005T000001@01000100P000@1000110000`40001^00030@0003X00P5K000000D00@00
0@0800040@000@@000<10000K`000`40000i00030@0005X0000200812P020@D000<10000K`000`40
000h0081G00001D000<10000L0000`40000f0081G@0001D000<10000L@000`40000e00030@0005`0
000E0081LP000`40000d00030@0005d0000E00030@00078000<10000<P020El0000E00030@0007<0
00<10000<0020F00000E00030@0007@000<10000;`000`40001O00005@000`40001d00030@0002h0
00<10000H00001D000<10000M@000`40000/0081HP0001D000<10000MP000`40000[00030@000640
000E00030@0007H000<10000:P000`40001R00005@020GP000<10000:0000`40001S00005@000`40
001h00030@0002H00P5U00005@000`40001i00030@0002D000<10000I00001D000<10000N@000`40
000T00030@0006D0000E00030@0007X000<100008P000`40001V00005@000`40001k00030@000200
00<10000I`0001D000<10000O0000`40000O00030@0006L0000E00030@0007d000<100007@000`40
001X00005@020Gl000<100006`000`40001Y00005@000`40001o00030@0001T000<10000JP0001D0
00<10000P0000`40000G00030@0006/0000E00030@0008400P4F00030@0006`0000E00030@0008<0
00<100004P000`40001]00005@000`40002400030@0000l00P5`00005@000`400025008130030G80
000=00@110000`40002700<11`020GD0000?00030@0000<00`6:00L1M`0000l000<100000`000`40
003o00T0000?00030@0000<000<10000o`0900003`000`40000300030@000?l02@0000d00`450003
0@000?l02@000001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-0.149373, -0.07747, 
  0.00695122, 0.00624851}}],

Cell[OutputFormData[
"\<\
Graphics[{{{Line[{{0.2000000666666666, 0.1593880259055336}, \
{0.2649071865166652, 0.195648514403892}, 
       {0.3356940797749978, 0.2440423916225631}, {0.4021749861416617, \
0.299318278931455}, {0.4661094524333249, 0.3626424312830573}, 
       {0.5341641453166539, 0.4418293105304601}, {0.5996723981249823, \
0.5294088348535694}, {0.6693008775249768, 0.6326824697276148}, 
       {0.7363829168499704, 0.7372560308586784}, {0.8009185160999635, \
0.8347105823583918}, {0.8335891492225671, 0.87956932449166}, 
       {0.8695743419416224, 0.9230870915944342}, {0.9040975619791227, \
0.9571752005555442}, {0.9356837277082806, 0.9803603922076112}, 
       {0.9524002956592292, 0.9891641886858677}, {0.9600916465892947, \
0.9923630251501608}, {0.9682909586306774, 0.9951676902697872}, 
       {0.972852010364931, 0.9964541763001768}, {0.9769874912887193, \
0.9974501311859611}, {0.9811924969123777, 0.9982957097437882}, 
       {0.9850613026796658, 0.99892423634891}, {0.9895892152014278, \
0.9994773309320679}, {0.9919709628680154, 0.9996890900923213}, 
       {0.9931853572962557, 0.9997760230581274}, {0.9944871969369856, \
0.9998534262468828}, {0.9966764679001453, 0.999946736572456}, 
       {0.9987203475596263, 0.9999921119988622}, {0.9999684680569057, \
0.9999999955252159}, {1.001150841308791, 0.9999935967088248}, 
       {1.003366899991604, 0.9999452650301947}, {1.005280328464284, \
0.9998654157152767}, {1.0073430156271, 0.999739789058422}, 
       {1.009290361387211, 0.9995835537997509}, {1.01107584108784, \
0.9994082092928902}, {1.015220937001828, 0.9988829124776732}, 
       {1.019585020226506, 0.9981516744674324}, {1.027813641029467, \
0.9962780986895703}, {1.036814734030168, 0.9934943389721812}, 
       {1.05284573975149, 0.9866704128554797}, {1.067760590999915, \
0.978237575458753}, {1.102128653833711, 0.9516594013612735}, 
       {1.133356547924887, 0.9198190236098085}, {1.200526291366523, \
0.8326319722302169}, {1.265149594733159, 0.7348632793021375}, 
       {1.333893124691461, 0.6277715055189711}, {1.400090214574762, \
0.5297418165959275}, {1.463740864383062, 0.4444592513942059}, 
       {1.531511740783029, 0.3652002523898085}, {1.596736177107994, \
0.3003083555413581}, {1.666080840024626, 0.2427017872630818}, 
       {1.732879062866257, 0.197012942603018}, {1.797130845632887, \
0.1608435588148125}, {1.799999933333333, 0.1593869053442523}}]}}, 
   {{Line[{{0.2000000666666666, 0.244601871939689}, {0.2649071865166652, \
0.2772020011987406}, {0.3356940797749978, 0.3195424522284071}, 
       {0.4021749861416617, 0.3670284870254842}, {0.4661094524333249, \
0.4209751794284795}, {0.5341641453166539, 0.4884879286107539}, 
       {0.5996723981249823, 0.5639094539052691}, {0.6693008775249768, \
0.6545708560730586}, {0.7363829168499704, 0.7488738265422941}, 
       {0.8009185160999635, 0.839455434312809}, {0.8335891492225671, \
0.8821231006659598}, {0.8695743419416224, 0.9241420614144351}, 
       {0.9040975619791227, 0.9575051181424765}, {0.9356837277082806, \
0.980429835531525}, {0.9524002956592292, 0.9891851050608611}, 
       {0.9600916465892947, 0.9923732607415109}, {0.9682909586306774, \
0.9951716311569247}, {0.972852010364931, 0.9964561952383215}, 
       {0.9769874912887193, 0.9974510825872711}, {0.9811924969123777, \
0.9982960460215224}, {0.9850613026796658, 0.9989242923509285}, 
       {0.9895892152014278, 0.9994772716104408}, {0.9919709628680154, \
0.9996890231339175}, {0.9931853572962557, 0.9997759602409063}, 
       {0.9944871969369856, 0.9998533718016867}, {0.9966764679001453, \
0.9999467017641912}, {0.9987203475596263, 0.9999920983670254}, 
       {0.9999684680569057, 0.9999999952022491}, {1.001150841308791, \
0.9999936090659604}, {1.003366899991604, 0.9999453018165279}, 
       {1.005280328464284, 0.9998654760295609}, {1.0073430156271, \
0.9997398809565678}, {1.009290361387211, 0.9995836863966786}, 
       {1.01107584108784, 0.9994083938894881}, {1.015220937001828, \
0.9988833070902877}, {1.019585020226506, 0.9981525138981043}, 
       {1.027813641029467, 0.9962809352763162}, {1.036814734030168, \
0.9935024667510278}, {1.05284573975149, 0.9867033332301096}, 
       {1.067760590999915, 0.9783242850601697}, {1.102128653833711, \
0.9520812528336019}, {1.133356547924887, 0.9209669133172846}, 
       {1.200526291366523, 0.8374967659116657}, {1.265149594733159, \
0.7466873163956067}, {1.333893124691461, 0.6502113436744459}, 
       {1.400090214574762, 0.5642011655791151}, {1.463740864383062, \
0.4907406597365953}, {1.531511740783029, 0.4231537100236014}, 
       {1.596736177107994, 0.367875926207845}, {1.666080840024626, \
0.3183832169086275}, {1.732879062866257, 0.278412229560401}, 
       {1.797130845632887, 0.2459320058256204}, {1.799999933333333, \
0.244601871939689}}]}}}, 
  {PlotRange -> Automatic, AspectRatio -> GoldenRatio^(-1), DisplayFunction \
:> $DisplayFunction, ColorOutput -> Automatic, 
   Axes -> Automatic, AxesOrigin -> Automatic, PlotLabel -> None, AxesLabel \
-> None, Ticks -> Automatic, GridLines -> None, Prolog -> {}, 
   Epilog -> {}, AxesStyle -> Automatic, Background -> Automatic, \
DefaultColor -> Automatic, DefaultFont :> $DefaultFont, 
   RotateLabel -> True, Frame -> False, FrameStyle -> Automatic, FrameTicks \
-> Automatic, FrameLabel -> None, PlotRegion -> Automatic, 
   ImageSize -> Automatic, TextStyle :> $TextStyle, FormatType :> \
$FormatType}]\
\>", "\<\
-Graphics-\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
(  1  +  (   sigmaHFactor[sigmaResonanceEnergyHigh]   deltaHHigh^2 
           + sigmaXiFactor[sigmaResonanceEnergyHigh] deltaXiHigh^2 
         )*( b1Half-b1 )^2 
)^(-1)\
\>", "Input"],

Cell[OutputFormData["\<\
0.5\
\>", "\<\
0.5\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
e=resonanceEnergyHigh;
b1Half=b1-peakWidthHigh;
tau2[ b1Half
     ,I beta1[m1,e,V1]
     ,m1
     ,w
     ,k[m,e]
     ,m
     ,b2
     ,I beta1[m2,e,V2]
     ,m2
    ]\
\>", "Input"],

Cell[OutputFormData["\<\
0.4552740756132648\
\>", 
"\<\
0.455274\
\>"], "Output"]
}, Open  ]],

Cell["\<\
(* Lower Peak LMS Paper \
************************************************************ *)\
\>", "Input"],

Cell[CellGroupData[{

Cell["\<\

deltaXiLow=deltaXiB1eLeV1V2[ k[m,resonanceEnergyLow]
                            ,m
                            ,b1
                            ,I beta1[m1,resonanceEnergyLow,V1]
                            ,m1
                           ]\
\>", "Input"],

Cell[OutputFormData["\<\
-2.423015793575088*^6\
\>", "\<\
           6
-2.42302 10\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
deltaHLow=deltaHB1eLeV1V2[  k[m,resonanceEnergyLow]
                            ,m
                            ,b1
                            ,beta1[m1,resonanceEnergyLow,V1]
                            ,m1
                          ]
\
\>", "Input"],

Cell[OutputFormData["\<\
1.035155793180803*^10\
\>", "\<\
          10
1.03516 10\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

peakWidthLow=(     sigmaHFactor[sigmaResonanceEnergyLow]   deltaHLow^2
                +  sigmaXiFactor[sigmaResonanceEnergyLow]  deltaXiLow^2
              )^(-1/2)\
\>", "Input"],

Cell[OutputFormData["\<\
1.122379305838816*^-9\
\>", "\<\
          -9
1.12238 10\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\



peakWidthLow/nanometer
\
\>", "Input"],

Cell[OutputFormData["\<\
1.122379305838816\
\>", "\<\
1.12238\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

peakWidthLow/b1\
\>", "Input"],

Cell[OutputFormData["\<\
0.280594826459704\
\>", "\<\
0.280595\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

e=resonanceEnergyLow;
b1Half=b1+peakWidthLow;
tau2[ b1Half
     ,I beta1[m1,e,V1]
     ,m1
     ,w
     ,k[m,e]
     ,m
     ,b2
     ,I beta1[m2,e,V2]
     ,m2
    ]
\
\>", "Input"],

Cell[OutputFormData["\<\
0.4370923456972744\
\>", 
"\<\
0.437092\
\>"], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

e=resonanceEnergyLow;
b1Half=b1-peakWidthLow;
tau2[ b1Half
     ,I beta1[m1,e,V1]
     ,m1
     ,w
     ,k[m,e]
     ,m
     ,b2
     ,I beta1[m2,e,V2]
     ,m2
    ]
\
\>", "Input"],

Cell[OutputFormData["\<\
0.4370883346880503\
\>", 
"\<\
0.437088\
\>"], "Output"]
}, Open  ]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1152}, {0, 900}},
WindowSize->{1044, 721},
WindowMargins->{{Automatic, 6}, {45, Automatic}}
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 157, 2, 43, "Input"],
Cell[1891, 55, 879, 19, 188, "Print"]
}, Open  ]],
Cell[2785, 77, 121, 4, 27, "Input"],

Cell[CellGroupData[{
Cell[2931, 85, 273, 8, 117, "Input"],
Cell[3207, 95, 94, 5, 34, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3338, 105, 264, 8, 117, "Input"],
Cell[3605, 115, 96, 5, 34, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3738, 125, 197, 6, 72, "Input"],
Cell[3938, 133, 98, 5, 34, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4073, 143, 40, 0, 27, "Input"],
Cell[4116, 145, 78, 4, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4231, 154, 34, 0, 27, "Input"],
Cell[4268, 156, 79, 4, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4384, 165, 193, 13, 192, "Input"],
Cell[4580, 180, 81, 5, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4698, 190, 338, 20, 297, "Input"],
Cell[5039, 212, 15028, 489, 186, 5289, 364, "GraphicsData", 
"PostScript", "Graphics"],
Cell[20070, 703, 5436, 86, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25543, 794, 195, 5, 72, "Input"],
Cell[25741, 801, 60, 4, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25838, 810, 193, 13, 192, "Input"],
Cell[26034, 825, 81, 5, 25, "Output"]
}, Open  ]],
Cell[26130, 833, 114, 3, 27, "Input"],

Cell[CellGroupData[{
Cell[26269, 840, 265, 8, 117, "Input"],
Cell[26537, 850, 99, 5, 34, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26673, 860, 261, 8, 117, "Input"],
Cell[26937, 870, 98, 5, 34, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27072, 880, 191, 5, 72, "Input"],
Cell[27266, 887, 98, 5, 34, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27401, 897, 51, 6, 87, "Input"],
Cell[27455, 905, 78, 4, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27570, 914, 41, 3, 42, "Input"],
Cell[27614, 919, 79, 4, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27730, 928, 193, 15, 222, "Input"],
Cell[27926, 945, 81, 5, 25, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28044, 955, 193, 15, 222, "Input"],
Cell[28240, 972, 81, 5, 25, "Output"]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

